OC.L10N.register(
    "comments",
    {
    "Comments" : "Komentáře",
    "You commented" : "Okomentovali jste",
    "{author} commented" : "{author} okomentoval(a)",
    "You commented on %1$s" : "Okomentovali jste %1$s",
    "You commented on {file}" : "Okomentovali jste {file}",
    "%1$s commented on %2$s" : "%1$s okomentoval(a) %2$s",
    "{author} commented on {file}" : "{author} okomentoval(a) {file}",
    "<strong>Comments</strong> for files" : "<strong>Komentáře</strong> k souborům",
    "Files" : "Soubory",
    "You were mentioned on \"{file}\", in a comment by an account that has since been deleted" : "Byli jste zmíněni u souboru „{file}“, v komentáři od účtu, který byl později smazán",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} vás zmínil(a) v komentáři u „{file}“",
    "Files app plugin to add comments to files" : "Zásuvný modul do aplikace Soubory pro přidávání komentářů k souborům",
    "Edit comment" : "Upravit komentář",
    "Delete comment" : "Smazat komentář",
    "Cancel edit" : "Zrušit úpravu",
    "New comment" : "Nový komentář",
    "Write a comment …" : "Napsat komentář…",
    "Post comment" : "Odeslat komentář",
    "@ for mentions, : for emoji, / for smart picker" : "@ pro zmínění, : pro emotikony, / pro inteligentní výběr",
    "Could not reload comments" : "Znovunačtení komentářů se nezdařilo",
    "Failed to mark comments as read" : "Nepodařilo se označit komentáře jako přečtené",
    "Unable to load the comments list" : "Nedaří se načíst seznam komentářů",
    "No comments yet, start the conversation!" : "Zatím bez komentářů, začněte konverzaci!",
    "No more messages" : "Žádné další zprávy",
    "Retry" : "Zkusit znovu",
    "_1 new comment_::_{unread} new comments_" : ["Jeden nový komentář","{unread} nové komentáře","{unread} nových komentářů","{unread} nové komentáře"],
    "Comment" : "Komentář",
    "An error occurred while trying to edit the comment" : "Došlo k chybě při pokusu o úpravu komentáře",
    "Comment deleted" : "Komentář smazán",
    "An error occurred while trying to delete the comment" : "Došlo k chybě při pokusu o smazání komentáře",
    "An error occurred while trying to create the comment" : "Došlo k chybě při pokusu o vytvoření komentáře"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
